#!/usr/bin/python

# tolerance_judge.py: accepts input within a certain tolerance
# usage: tolerance_judge.py [eps] [output] [expected]
# if can't find files, outputs "file not found"
# if formatting error, outputs "format error"
# if incorrect, outputs "incorrect"
# if one is prefix of another, outputs "eof"
# if correct, outputs NOTHING

import sys
from itertools import izip
from decimal import *

if len(sys.argv) != 4:
    print "usage: tolerance_judge.py [eps] [output] [expected]"
    sys.exit()

# parse epsilon
try:
    eps = Decimal( sys.argv[1] )
except:
    print "error parsing epsilon"
    sys.exit()

# open files
try:
    ofile = open(sys.argv[2], "r")
    efile = open(sys.argv[3], "r")
except:
    print "file not found"
    sys.exit()

lineno = 0

tinyeps = Decimal("1e-20")

# do tests
while True:
    lineno += 1

    oline = ofile.readline()
    eline = efile.readline()

    if not oline and not eline:
        # simultaneous eof
        sys.exit()
    elif not oline or not eline:
        # non-simultaneous eof, check if just a newline
        oline += ofile.read()
        eline += efile.read()
        if oline.strip("\n") == "" and eline.strip("\n") == "":
            sys.exit()
        else:
            print "eof"
            sys.exit()

    try:
        out = Decimal(oline)
        expect = Decimal(eline)
    except:
        print "format error"
        sys.exit()

    abs_err = abs(out - expect) 
    if abs_err > eps:
        print "incorrect (line %d, out %.06lf, expect %.06lf)" % (lineno, out, expect)
        sys.exit()
